@@ -335,11 +335,11 @@ class MObject(object):
         raw_k = None
         if not raw:
             raw_k = k
-            if k in self.BELONGS_TO and (k not in self._m__relations or not isinstance(self._m__relations[k], MObject)):
+            if k in self.BELONGS_TO and (k not in self._m__relations or not isinstance(self._m__relations[k], BelongsTo)):
                 self._m__relations[k] = BelongsTo.load(self, k, self.BELONGS_TO[k])
-            elif k in self.HAS_MANY and (k not in self._m__relations or not isinstance(self._m__relations[k], MCursor)):
+            elif k in self.HAS_MANY and (k not in self._m__relations or not isinstance(self._m__relations[k], HasMany)):
                 self._m__relations[k] = HasMany.load(self, k, self.HAS_MANY[k])
-            elif k in self.BELONGS_TO_MANY and (k not in self._m__relations or not isinstance(self._m__relations[k], MCursor)):
+            elif k in self.BELONGS_TO_MANY and (k not in self._m__relations or not isinstance(self._m__relations[k], BelongsToMany)):
                 self._m__relations[k] = BelongsToMany.load(self, k, self.BELONGS_TO_MANY[k])
 
         if k in self.DEFAULT_VALUES and default is None:
@@ -504,6 +504,8 @@ class MObject(object):
 
         if cls.MONGO_ID and not isinstance(id, bson.ObjectId):
             id = bson.ObjectId(id)
+        if 'filter' not in kwargs:
+            kwargs['filter'] = False
         return cls.find_one_by_('_id', id, **kwargs)
 
     @classmethod
