@@ -63,19 +63,19 @@ class _Relationship(object):
         return getattr(module, module_name)
 
     def __init__(self, data, active, related, key, foreign_key):
-        self._data = data
-        self._active = active
-        self._related = related
-        self._key = key
-        self._foreign_key = foreign_key
+        self._rel__data = data
+        self._rel__active = active
+        self._rel__related = related
+        self._rel__key = key
+        self._rel__foreign_key = foreign_key
 
 
 class _Multi(object):
     def __iter__(self):
-        return iter(self._data)
+        return iter(self._rel__data)
 
     def __len__(self):
-        return len(self._data)
+        return len(self._rel__data)
 
     def __contains__(self, v):
         if not isinstance(v, PRIMITIVES):
@@ -83,7 +83,7 @@ class _Multi(object):
         return v in self.keys()
 
     def __getitem__(self, i):
-        return self._data.__getitem__(i)
+        return self._rel__data.__getitem__(i)
 
     def iteritems(self):
         for x in self:
@@ -117,9 +117,9 @@ class HasMany(_Relationship, _Multi):
         .. note:: This automatically commits the change to the database.
         '''
 
-        related_obj = self._related.find_by_id(val) if isinstance(val, PRIMITIVES) else val
+        related_obj = self._rel__related.find_by_id(val) if isinstance(val, PRIMITIVES) else val
         if related_obj:
-            setattr(related_obj, self._foreign_key, self._active.id)
+            setattr(related_obj, self._foreign_key, self._rel__active.id)
             related_obj.save()
         # TODO: add to self._data (cursor)
 
@@ -134,9 +134,9 @@ class HasMany(_Relationship, _Multi):
         .. note:: This automatically commits the change.
         '''
 
-        related_obj = self._related.find_by_id(val) if isinstance(val, PRIMITIVES) else val
+        related_obj = self._rel__related.find_by_id(val) if isinstance(val, PRIMITIVES) else val
         if related_obj:
-            delattr(related_obj, self._foreign_key)
+            delattr(related_obj, self._rel__foreign_key)
             related_obj.save()
 
 
@@ -146,6 +146,17 @@ class BelongsTo(_Relationship):
 
     TYPE = 2
 
+    def __getattr__(self, k):
+        if k.startswith('_rel_'):
+            return self.__dict__[k]
+        return getattr(self._rel__data, k)
+
+    def __setattr__(self, k, v):
+        if k.startswith('_rel_'):
+            self.__dict__[k] = v
+        else:
+            setattr(self._rel__data, k, v)
+
 
 class BelongsToMany(_Relationship, _Multi):
     ''' Class to represent *belongs to many* relationships.
@@ -166,11 +177,11 @@ class BelongsToMany(_Relationship, _Multi):
         '''
 
         if not isinstance(val, PRIMITIVES):
-            val = val.__getattr__(self._foreign_key, raw=True)
+            val = val.__getattr__(self._rel__foreign_key, raw=True)
 
-        fin = self._active.__getattr__(self._key, raw=True, default=[])
+        fin = self._rel__active.__getattr__(self._rel__key, raw=True, default=[])
         fin.append(val)
-        setattr(self._active, self._key, fin)
+        setattr(self._rel__active, self._rel__key, fin)
         # TODO: add to self._data (cursor)
 
     def remove(self, val):
@@ -183,11 +194,11 @@ class BelongsToMany(_Relationship, _Multi):
         '''
 
         if not isinstance(val, PRIMITIVES):
-            val = val.__getattr__(self._foreign_key, raw=True)
+            val = val.__getattr__(self._rel__foreign_key, raw=True)
 
-        fin = self._active.__getattr__(self._key, raw=True, default=[])
+        fin = self._rel__active.__getattr__(self._rel__key, raw=True, default=[])
         if val in fin:
             fin = [x for x in fin if x != val]
-            setattr(self._active, self._key, fin)
+            setattr(self._rel__active, self._rel__key, fin)
         # TODO: add to self._data (cursor)
 
